@@ -266,17 +266,21 @@ class RequestRevisionsAs(flow.Action):
                 self.root().session().log_error(f"Revision {revision_oid} does not exist")
                 continue
 
-            request_action_oid = revision_oid + "/request_as"
-            self.root().session().cmds.Flow.set_value(
-                request_action_oid + "/requesting_site_name",
-                requesting_site_name
-            )
-            self.root().session().cmds.Flow.set_value(
-                request_action_oid + "/requested_site_name",
-                requested_site_name
-            )
+            revision = self.root().get_object(revision_oid)
+            
+            try:
+                revision.request_as.requesting_site_name.set(requesting_site_name)
+                revision.request_as.requested_site_name.set(requested_site_name)
+            except ValueError:
+                name = revision.name()
+                self.root().session().log_error((
+                    f"Revision {name} is either already available on requesting site {requesting_site_name} "
+                    f"or not available on requested site {requested_site_name}"
+                ))
+                continue
+
             processed_revisions += 1
-            self.root().session().cmds.Flow.run_action(request_action_oid, None)
+            revision.request_as.run(None)
         
         msg = "<h3>Request revisions</h3>"
         msg += f"<b>{processed_revisions}</b> revision(s) processed."
@@ -355,6 +359,8 @@ class ProjectSettings(flow.Object):
     project_nice_name = flow.Param()
     project_thumbnail = flow.Param().ui(editor='textarea')
 
+    non_editable_files = flow.Param("")
+
 
 class ExchangeSiteChoiceValue(flow.values.ChoiceValue):
 
@@ -423,7 +429,7 @@ class Admin(flow.Object):
 
     _project = flow.Parent()
 
-    project_settings = flow.Child(ProjectSettings)
+    project_settings = flow.Child(ProjectSettings).injectable()
     settings = flow.Child(ContextualView)
     users = flow.Child(Users)
     kitsu = flow.Child(KitsuConfig)
@@ -568,7 +574,8 @@ class Project(flow.Object):
             
             if not user_name:
                 # Create user profile if not registered
-                self.admin.users.add_user(kitsu_id)
+                user = self.admin.users.add_user(kitsu_id)
+                user_name = user.name()
             
             self.set_user(user_name)
 
